<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<span id="branding" style="font-size: 0.8em; color: #999999;">Proudly Powered by <a href="http://www.socialengine.com" target="_blank">SocialEngine <?php if($this->version) { ?><?php echo " v".$this->version; ?><?php } ?></a></span>
