<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Widget_BrandingController extends Engine_Content_Widget_Abstract {

  public function indexAction() {
  
    $this->view->version = 0;
    $this->view->showVersion = $showVersion = $this->_getParam('showVersion', 0);
    if(!empty($showVersion)) {
      $table = Engine_Api::_()->getDbTable('modules', 'core');
      $version = $table->select()
                    ->from($table->info('name'), 'version')
                    ->query()
                    ->fetchColumn();
      $this->view->version = $version;
    }
  }
}
